Welcome to AlekSIS-App-DashboardFeeds' documentation!
==============================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   user/00_index
   admin/00_index
   dev/00_index
   ref/00_index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
